@@ -32,10 +32,7 @@ import org.testng.Assert;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
-import java.io.ByteArrayInputStream;
-import java.io.InputStream;
-import java.io.File;
-import java.io.IOException;
+import java.io.*;
 import java.util.Arrays;
 import java.util.NoSuchElementException;
 
@@ -50,14 +47,8 @@ public class CRAMFileReaderTest extends HtsjdkTest {
     private static final ReferenceSource REFERENCE = createReferenceSource();
     private static final File INDEX_FILE = new File(TEST_DATA_DIR, "cram_with_crai_index.cram.crai");
 
-
-    @BeforeClass
-    public void initClass() {
-        Log.setGlobalLogLevel(Log.LogLevel.ERROR);
-    }
-
     private static ReferenceSource createReferenceSource() {
-        byte[] refBases = new byte[10 * 10];
+        final byte[] refBases = new byte[10 * 10];
         Arrays.fill(refBases, (byte) 'A');
         InMemoryReferenceSequenceFile rsf = new InMemoryReferenceSequenceFile();
         rsf.add("chr1", refBases);
@@ -66,40 +57,43 @@ public class CRAMFileReaderTest extends HtsjdkTest {
 
     // constructor 1: CRAMFileReader(final File cramFile, final InputStream inputStream)
 
-    @Test(description = "Test CRAMReader 1 reference required", expectedExceptions = IllegalStateException.class)
+    @Test(description = "Test CRAMReader 1 reference required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader1_ReferenceRequired() {
-        InputStream bis = null;
+        final InputStream bis = null;
         // assumes that reference_fasta property is not set and the download service is not enabled
-        new CRAMFileReader(CRAM_WITH_CRAI, bis);
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, bis);
+        reader.getIterator().hasNext();
     }
 
     // constructor 2: CRAMFileReader(final File cramFile, final InputStream inputStream, final ReferenceSource referenceSource)
 
     @Test(description = "Test CRAMReader 2 reference required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader2ReferenceRequired() {
-        InputStream bis =  null;
-        new CRAMFileReader(CRAM_WITH_CRAI, bis, null);
+        final InputStream bis =  null;
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, bis, null);
+        reader.getIterator().hasNext();
     }
 
     @Test(description = "Test CRAMReader 2 input required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader2_InputRequired() {
-        File file = null;
-        InputStream bis = null;
-        new CRAMFileReader(file, bis, createReferenceSource());
+        final File file = null;
+        final InputStream bis = null;
+        final CRAMFileReader reader = new CRAMFileReader(file, bis, createReferenceSource());
+        reader.getIterator().hasNext();
     }
 
     @Test
     public void testCRAMReader2_ShouldAutomaticallyFindCRAMIndex() {
-        InputStream inputStream = null;
-        CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, inputStream, REFERENCE);
+        final InputStream inputStream = null;
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, inputStream, REFERENCE);
         reader.getIndex();
         Assert.assertTrue(reader.hasIndex(), "Can't find CRAM existing index.");
     }
 
     @Test(expectedExceptions = SAMException.class)
     public void testCRAMReader2_WithoutCRAMIndex() {
-        InputStream inputStream = null;
-        CRAMFileReader reader = new CRAMFileReader(CRAM_WITHOUT_CRAI, inputStream, REFERENCE);
+        final InputStream inputStream = null;
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITHOUT_CRAI, inputStream, REFERENCE);
         reader.getIndex();
     }
 
@@ -107,38 +101,39 @@ public class CRAMFileReaderTest extends HtsjdkTest {
 
     @Test(description = "Test CRAMReader 3 reference required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader3_RequiredReference() {
-        File indexFile = null;
-        ReferenceSource refSource = null;
-        new CRAMFileReader(CRAM_WITH_CRAI, indexFile, refSource);
+        final File indexFile = null;
+        final ReferenceSource refSource = null;
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, indexFile, refSource);
+        reader.getIterator().hasNext();
     }
 
     @Test(description = "Test CRAMReader 3 input required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader3_InputRequired() {
-        File inputFile = null;
-        File indexFile = null;
+        final File inputFile = null;
+        final File indexFile = null;
         ReferenceSource refSource = null;
         new CRAMFileReader(inputFile, indexFile, refSource);
     }
 
     @Test
     public void testCRAMReader3_ShouldAutomaticallyFindCRAMIndex() {
-        File indexFile = null;
-        CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, indexFile, REFERENCE);
+        final File indexFile = null;
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, indexFile, REFERENCE);
         reader.getIndex();
-        Assert.assertTrue(reader.hasIndex(), "Can't find existing CRAM index.");
+        Assert.assertTrue(reader.hasIndex(), "Can't find CRAM index.");
     }
 
     @Test
     public void testCRAMReader3_ShouldUseCRAMIndex() {
-        CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, INDEX_FILE, REFERENCE);
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, INDEX_FILE, REFERENCE);
         reader.getIndex();
-        Assert.assertTrue(reader.hasIndex(), "Can't find existing CRAM index.");
+        Assert.assertTrue(reader.hasIndex(), "Can't find CRAM index.");
     }
 
     @Test(expectedExceptions = SAMException.class)
     public void testCRAMReader3_WithoutCRAMIndex() {
-        File indexFile = null;
-        CRAMFileReader reader = new CRAMFileReader(CRAM_WITHOUT_CRAI, indexFile, REFERENCE);
+        final File indexFile = null;
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITHOUT_CRAI, indexFile, REFERENCE);
         reader.getIndex();
     }
 
@@ -146,26 +141,27 @@ public class CRAMFileReaderTest extends HtsjdkTest {
 
     @Test(description = "Test CRAMReader 4 reference required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader4_ReferenceRequired() {
-        ReferenceSource refSource = null;
-        new CRAMFileReader(CRAM_WITH_CRAI, refSource);
+        final ReferenceSource refSource = null;
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, refSource);
+        reader.getIterator().hasNext();
     }
 
     @Test(description = "Test CRAMReader 4 input required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader4_InputRequired() {
-        File inputFile = null;
+        final File inputFile = null;
         new CRAMFileReader(inputFile, createReferenceSource());
     }
 
     @Test
     public void testCRAMReader4_ShouldAutomaticallyFindCRAMIndex() {
-        CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, REFERENCE);
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, REFERENCE);
         reader.getIndex();
         Assert.assertTrue(reader.hasIndex(), "Can't find existing CRAM index.");
     }
 
     @Test(expectedExceptions = SAMException.class)
     public void testCRAMReader4_WithoutCRAMIndex() {
-        CRAMFileReader reader = new CRAMFileReader(CRAM_WITHOUT_CRAI, REFERENCE);
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITHOUT_CRAI, REFERENCE);
         reader.getIndex();
     }
 
@@ -173,16 +169,18 @@ public class CRAMFileReaderTest extends HtsjdkTest {
     //          final ReferenceSource referenceSource, final ValidationStringency validationStringency)
     @Test(description = "Test CRAMReader 5 reference required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader5_ReferenceRequired() throws IOException {
-        InputStream bis = new ByteArrayInputStream(new byte[0]);
-        SeekableFileStream sfs = null;
-        ReferenceSource refSource = null;
-        new CRAMFileReader(bis, sfs, refSource, ValidationStringency.STRICT);
+        try (final FileInputStream fis = new FileInputStream(CRAM_WITH_CRAI)) {
+            final SeekableFileStream sfs = null;
+            final ReferenceSource refSource = null;
+            final CRAMFileReader reader = new CRAMFileReader(fis, sfs, refSource, ValidationStringency.STRICT);
+            reader.getIterator().hasNext();
+        }
     }
 
     @Test(description = "Test CRAMReader 5 input required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader5_InputRequired() throws IOException {
-        InputStream bis = null;
-        SeekableFileStream sfs = null;
+        final InputStream bis = null;
+        final SeekableFileStream sfs = null;
         new CRAMFileReader(bis, sfs, createReferenceSource(), ValidationStringency.STRICT);
     }
 
@@ -190,10 +188,12 @@ public class CRAMFileReaderTest extends HtsjdkTest {
     //                final ValidationStringency validationStringency)
     @Test(description = "Test CRAMReader 6 reference required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader6_ReferenceRequired() throws IOException {
-        InputStream bis = new ByteArrayInputStream(new byte[0]);
-        File file = null;
-        ReferenceSource refSource = null;
-        new CRAMFileReader(bis, file, refSource, ValidationStringency.STRICT);
+        try (final FileInputStream fis = new FileInputStream(CRAM_WITH_CRAI)) {
+            final File file = null;
+            final ReferenceSource refSource = null;
+            final CRAMFileReader reader = new CRAMFileReader(fis, file, refSource, ValidationStringency.STRICT);
+            reader.getIterator().hasNext();
+        }
     }
 
     @Test(description = "Test CRAMReader 6 input required", expectedExceptions = IllegalArgumentException.class)
@@ -208,7 +208,8 @@ public class CRAMFileReaderTest extends HtsjdkTest {
     @Test(description = "Test CRAMReader 7 reference required", expectedExceptions = IllegalArgumentException.class)
     public void testCRAMReader7_ReferenceRequired() throws IOException {
         ReferenceSource refSource = null;
-        new CRAMFileReader(CRAM_WITH_CRAI, CRAM_WITH_CRAI, refSource, ValidationStringency.STRICT);
+        final CRAMFileReader reader = new CRAMFileReader(CRAM_WITH_CRAI, CRAM_WITH_CRAI, refSource, ValidationStringency.STRICT);
+        reader.getIterator().hasNext();
     }
 
     @Test
