@@ -28,6 +28,9 @@ import htsjdk.HtsjdkTest;
 import htsjdk.samtools.SAMException;
 import htsjdk.samtools.seekablestream.SeekableFileStream;
 import htsjdk.samtools.util.CloserUtil;
+import htsjdk.samtools.util.GZIIndex;
+import htsjdk.samtools.util.IOUtil;
+import htsjdk.samtools.util.RuntimeIOException;
 import htsjdk.samtools.util.StringUtil;
 import org.testng.Assert;
 import org.testng.annotations.DataProvider;
@@ -36,6 +39,10 @@ import org.testng.annotations.Test;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
+import java.io.IOException;
+import java.nio.file.Files;
+import java.nio.file.Path;
+import java.nio.file.StandardCopyOption;
 
 /**
  * Test the indexed fasta sequence file reader.
@@ -45,6 +52,7 @@ public class AbstractIndexedFastaSequenceFileTest extends HtsjdkTest {
     private static final File SEQUENCE_FILE = new File(TEST_DATA_DIR,"Homo_sapiens_assembly18.trimmed.fasta");
     private static final File SEQUENCE_FILE_INDEX = new File(TEST_DATA_DIR,"Homo_sapiens_assembly18.trimmed.fasta.fai");
     private static final File SEQUENCE_FILE_BGZ = new File(TEST_DATA_DIR,"Homo_sapiens_assembly18.trimmed.fasta.gz");
+    private static final File SEQUENCE_FILE_GZI = new File(TEST_DATA_DIR,"Homo_sapiens_assembly18.trimmed.fasta.gz.gzi");
     private static final File SEQUENCE_FILE_NODICT = new File(TEST_DATA_DIR,"Homo_sapiens_assembly18.trimmed.nodict.fasta");
 
     private final String firstBasesOfChrM = "GATCACAGGTCTATCACCCT";
@@ -66,6 +74,12 @@ public class AbstractIndexedFastaSequenceFileTest extends HtsjdkTest {
 
     @DataProvider(name="comparative")
     public Object[][] provideOriginalAndNewReaders() throws FileNotFoundException {
+        GZIIndex gziIndex;
+        try {
+            gziIndex = GZIIndex.loadIndex(SEQUENCE_FILE_GZI.toPath());
+        } catch (IOException e) {
+            throw new RuntimeIOException(e);
+        }
         return new Object[][] {
                 new Object[] { ReferenceSequenceFileFactory.getReferenceSequenceFile(SEQUENCE_FILE),
                                                new IndexedFastaSequenceFile(SEQUENCE_FILE) },
@@ -83,6 +97,11 @@ public class AbstractIndexedFastaSequenceFileTest extends HtsjdkTest {
                         SEQUENCE_FILE_BGZ, true),
                                                new BlockCompressedIndexedFastaSequenceFile(
                                                        SEQUENCE_FILE_BGZ.toPath()) },
+                new Object[] { ReferenceSequenceFileFactory.getReferenceSequenceFile(SEQUENCE_FILE_BGZ),
+                                                new BlockCompressedIndexedFastaSequenceFile(
+                                                        SEQUENCE_FILE_BGZ.getAbsolutePath(), new SeekableFileStream(SEQUENCE_FILE_BGZ),
+                                                        new FastaSequenceIndex(new FileInputStream(SEQUENCE_FILE_INDEX)), null,
+                                                        gziIndex) },
                 new Object[] { ReferenceSequenceFileFactory.getReferenceSequenceFile(SEQUENCE_FILE.getAbsolutePath(),
                                                        new SeekableFileStream(SEQUENCE_FILE), new FastaSequenceIndex(new FileInputStream(SEQUENCE_FILE_INDEX))),
                                                new IndexedFastaSequenceFile(SEQUENCE_FILE.getAbsolutePath(), new SeekableFileStream(SEQUENCE_FILE),
@@ -338,4 +357,16 @@ public class AbstractIndexedFastaSequenceFileTest extends HtsjdkTest {
     public void testBadInputForBlockCompressedIndexedFastaSequenceFile() throws Exception {
         new BlockCompressedIndexedFastaSequenceFile(SEQUENCE_FILE.toPath());
     }
+
+    @Test
+    public void testCanCreateBlockCompressedIndexedWithSpecifiedGZIAndDict() throws IOException {
+        final Path moved = Files.createTempFile("moved", ".fasta.gz");
+        Files.copy(SEQUENCE_FILE_BGZ.toPath(), moved, StandardCopyOption.REPLACE_EXISTING);
+        IOUtil.deleteOnExit(moved);
+        try (ReferenceSequenceFile withNoAdacentIndex = new BlockCompressedIndexedFastaSequenceFile(moved, new FastaSequenceIndex(SEQUENCE_FILE_INDEX), GZIIndex.loadIndex(SEQUENCE_FILE_GZI.toPath()));
+             ReferenceSequenceFile withFilesAdjacent = new BlockCompressedIndexedFastaSequenceFile(SEQUENCE_FILE_BGZ.toPath())) {
+            Assert.assertEquals(withNoAdacentIndex.getSubsequenceAt("chrM", 100, 1000).getBases(),
+                    withFilesAdjacent.getSubsequenceAt("chrM", 100, 1000).getBases());
+        }
+    }
 }
